Algebraic Numbers and Number Fields
===================================

Number Fields
-------------

.. toctree::
   :maxdepth: 1

   sage/rings/number_field/number_field
   sage/rings/number_field/number_field_base
   sage/rings/number_field/number_field_rel

   sage/rings/number_field/splitting_field
   sage/rings/number_field/galois_group

Elements
--------

.. toctree::
   :maxdepth: 1

   sage/rings/number_field/number_field_element
   sage/rings/number_field/number_field_element_quadratic
   sage/rings/number_field/bdd_height

Morphisms
---------

.. toctree::
   :maxdepth: 1

   sage/rings/number_field/morphism
   sage/rings/number_field/homset
   sage/rings/number_field/number_field_morphisms
   sage/rings/number_field/maps
   sage/rings/number_field/structure

Orders, Ideals and Ideal Classes
--------------------------------

.. toctree::
   :maxdepth: 1

   sage/rings/number_field/order
   sage/rings/number_field/number_field_ideal
   sage/rings/number_field/number_field_ideal_rel
   sage/rings/number_field/order_ideal
   sage/rings/number_field/class_group
   sage/rings/number_field/unit_group
   sage/rings/number_field/S_unit_solver
   sage/rings/number_field/small_primes_of_degree_one
   sage/rings/number_field/selmer_group

Algebraic Numbers
-----------------

.. toctree::
   :maxdepth: 1

   sage/rings/qqbar
   sage/rings/universal_cyclotomic_field

Enumeration of Totally Real Fields
----------------------------------

.. toctree::
   :maxdepth: 1

   sage/rings/number_field/totallyreal
   sage/rings/number_field/totallyreal_rel
   sage/rings/number_field/totallyreal_data
   sage/rings/number_field/totallyreal_phc

.. include:: ../footer.txt
